@@ -3,6 +3,7 @@ from __future__ import annotations
 import typing
 from dataclasses import dataclass
 
+import bson
 import mongoengine as me
 
 from .base_document import BaseDocument
@@ -32,7 +33,7 @@ class UserModelDocument(BaseDocument):
 
 @dataclass
 class UserModel(BaseModel):
-    id: typing.Any = None
+    id: bson.ObjectId = None
 
     # TODO
     # def __init__(self, **attrs):
