@@ -17,7 +17,10 @@ def send_media_group(
     _locals = locals()
 
     for m in media:
-        m.parse_mode = m.parse_mode or ctx.parse_mode
+        if m.caption_entities:
+            m.parse_mode = None
+        else:
+            m.parse_mode = m.parse_mode or ctx.parse_mode
 
     return request(
         SendMediaGroup,
