@@ -106,7 +106,7 @@ def process_updates(updates: list[Update]):
 
         as_dict = cast(update, dict)
         as_string = yaml.dump(as_dict, allow_unicode=True, sort_keys=False)
-        as_string = '\n' + as_string + '\n'
+        as_string = f'Update ->\n{as_string}'
         logger.info(as_string)
 
 
